@@ -165,7 +165,7 @@ class ExamplesTest(unittest.TestCase):
             .set_note("A Note")
             .add_activationServiceNumber_seq()
                 .set_number_series('0612345678', '0612345678')
-                .set_tariff_info("1023,00", "1023,00", "1", "1023,00", "1023,00")
+                .set_tariff_info("1023,00", "1023,00", "1", "2", "3")
                 .set_pop("Test")
                 .finish()
             .build()
@@ -200,7 +200,7 @@ class ExamplesTest(unittest.TestCase):
             .set_planneddatetime("20190101121212")
             .add_tariffChangeServiceNumber_seq()
                 .set_number_series('0612345678', '0612345678')
-                .set_tariff_info("1023,00", "1023,00", "1", "1023,00", "1023,00")
+                .set_tariff_info("1023,00", "1023,00", "1", "2", "3")
                 .finish()
             .build()
         )
